<?php

require_once __DIR__."../../backendProject/database/DBCred.php";
require_once __DIR__."../../functions/generic_functions.php";

class Generic extends DBCred{
  public $has_db = true;
  public $backend = "";
  public $domain = "";
  protected $isConnected = false;
  private $server = "localhost";
  static $local_servers = ['localhost', 'localhost:8080', "127.0.0.1"];
  public static $mydb;
  public static $company;

  public function __construct($backend = ""){
    global $_SERVER;
    $this->server =  $_SERVER['SERVER_NAME'];
    $this->backend =  $backend;
  }

  public function closeDB(){
    if(!$this->isConnected){
      self::$mydb->close();
    }
  }

  //Connects to database if not connected
  public function connect(){
    if(!$this->isConnected){
      date_default_timezone_set("Africa/Lagos");

      $connect = (array_search($this->server, self::$local_servers) !==false ) ?
      [parent::$local_host,parent::$local_user,parent::$local_password,parent::$local_db] :
      [parent::$online_host,parent::$online_user,parent::$online_password,parent::$online_db];

      $db_handle = new MySQLi($connect[0],$connect[1],$connect[2],$connect[3]);
      if(empty($db_handle->connect_error)){
        $this->isConnected = true;
        self::$mydb = $db_handle;
        self::buildAllConstants($connect);
      }
    }
    return(self::$mydb);
  }

  protected function buildAllConstants($connect){
    $sql = "SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA = '{$connect[3]}'";
    $query = self::$mydb->query($sql) or die();
    while($row = $query->fetch_object()){
      $fields = self::getTableFields($row->TABLE_NAME);
      self::defineConstants($fields);
    }
  }

  public function getTableFields($table){
    $result = [];
    if(!$this->isConnected)die("Connect to database first (getTableFields)");
    if($row = self::$mydb->query("DESCRIBE $table")){
			while($r = $row->fetch_assoc()){
				$name = strtoupper($r['Field']);
				$result[] = trim(strtolower($name));
			}
		}
    return($result);
  }

  public function defineConstants($fields){
    foreach($fields as $name){
      $CONST = strtoupper($name);
			if(!defined($CONST."_DESC")) define($CONST."_DESC", $name." DESC");
			if(!defined($CONST."_ASC")) define($CONST."_ASC", $name." ASC");
	  }
  }

  public function getLocalServers(){
    return(self::$local_servers);
  }

  public function getServer(){
    return($this->server);
  }

  public function buildQuery($post){
    $build = [];
    foreach ($post as $key => $value) {
      $v=self::$mydb->real_escape_string($value);
      $build[] = "$key='{$v}'";
    }
    return(implode(", ", $build));
  }

  public function filterQuery($filter, $table, $searchCols = ""){
    $fields = $this::getTableFields($table); $search = "";
    $filter = str_replace("&", ",",$filter);
    $filter = str_replace(" AND ", " and ",$filter);
    $filter = str_replace(" and ", ",",$filter);
    if(!empty($searchCols)){
      $search = [];
      $searchCols = gettype($searchCols)== "array" ? $searchCols : explode(",", $searchCols);
      $filter = explode(",",$filter);
      $filters = explodeToKey("=", $filter);
      $fk = array_map("trim", array_keys($filters));
      $fv = array_map("trim", array_values($filters));
      $filters = array_combine($fk, $fv);
      if(isset($filters["keyword"])){
        $keyword = $filters["keyword"];
        foreach ($searchCols as $col) {
          if(array_search($col, $fields) !== false){$search[] = "$col LIKE '%$keyword%'";}
        }
        $search = count($search) ? "(".implode(" OR ", $search).")" : "";
      }
      $filter = implode(',',$filter);
    }
    if(!empty($filter)){
      $_flt = $filters = [];
      $arr = explode(',', $filter);
      // Supported symbols for filtering
      $explosives = ["=", "!=", "<", ">", "<>"];
      foreach($arr as $fltr){
        $explode_key = "=";
        foreach ($explosives as $xk => $xv) {
          if(gettype(stripos($fltr, $xv)) !== 'boolean'){ $explode_key = $xv; break; }
        }
        if(gettype(stripos($fltr, $explode_key)) !== 'boolean'){//if contains an explosive
          $_a = explode($explode_key ,str_replace("'","",$fltr));
          $_a[0] = cleanUp(trim($_a[0]));
          if(array_search($_a[0], $fields) !== false){//multiple keys
            $_flt[$_a[0]][] = "{$_a[0]}$explode_key'{$_a[1]}'";
          }
        }else if(gettype(stripos($fltr,' in ')) !== 'boolean'){
          $filters[] = get_in_clause($filter, $fltr);
        }
      }
      foreach ($_flt as $values) {
        $filters[] = count($values) > 1 ? "(".implode(" OR ", $values).")" : $values[0];
      }
      $filters = implode(" AND ", $filters);
      $filter = !empty($filters) && !empty($search) ? "$filters AND $search" : $filters.$search;
    }
    return($filter);
  }

  public function getFromTable($table, $filter = '', $page = 1, $pagesize = 1, $sort = "", $search = false, $cols = "*"){
    $content = [];
    $pagesize = empty($pagesize) ? 0 : $pagesize;
    $page = empty($page) ? 1 : $page;
    $recordstart = $pagesize == 0 ? 0 :($page - 1) * $pagesize;
    $limit = $pagesize == 0 ? "" : "LIMIT $recordstart, $pagesize";
    $sortOrder = !empty($sort) ? "ORDER BY ".$sort : "";
    $cols = is_array($cols) ? implode(',', $cols) : $cols;
    $filter = trim($filter);
    // see($filter);
    if(!empty($filter)){
      $filter = $this::filterQuery($filter, $table, $search);
      $filter = "WHERE $filter";
    }
    $filter = trim($filter);
		$sql = "SELECT $cols FROM $table $filter  ".$sortOrder." $limit";
    if(!$this->isConnected)die("Connect to database first (getFromTable)");
		$query = self::$mydb->query($sql) or die(self::$mydb->error."($sql)");
		while($row = $query->fetch_assoc()){
      $row = array_change_key_case($row);
			$row = (object) $row;
			$content[] = $row;
		}
		return($content);
	}

  public function submitForm($post){
    $response     = new stdClass;
    $paramControl = new ParamControl($this);
    $post = gettype($post) === 'array' ? (object)$post : $post;
    if(!empty($post->formName)){
      $fixed_values = $extra_values = "";
      $param = $paramControl->get_params($post->formName);
      if(count((array)$param) && isset($param->table) && isset($post->submitType)){
        $fields = $this::getTableFields($param->table);
        //Check for callback function before submission
        if(isset($param->pre_submit_function)){
          $post = call_user_func_array($param->pre_submit_function, [$post]);
          $post = gettype($post) === 'array' ? (object)$post : $post;
          if(!empty($post->error)){
            $response->status = 0;
            $response->message = $post->error;
            return $response;
          }
        }
        //If validation type is in strict mode
        /*If you don't supply 'validate_cols' table fields in params as array,
              it will validate all empty post fields value for strict validation.
          Even if not in strict mode and you supply validate_cols in param, it will handle the request with strictness
            with respect to the fields supplied in validate_cols;
        */
        if((isset($post->validation) && $post->validation === "strict") || !empty($param->validate_cols)){
          $validate_cols = !empty($param->validate_cols) ? $param->validate_cols : [];
          if(gettype($validate_cols) !== "array"){
            $response->status = 0;
            $response->message = "'validate_cols' must be array !!!";
            return $response;
          }
          if(count($validate_cols)){
            $unexist_col = array_diff($validate_cols,$fields);
            $unexist_post = array_diff($validate_cols,array_keys((array)$post));
            if(count($unexist_col)){
              $response->status = 0;
              $response->message="These table columns don't exist: ".implode(',',$unexist_col);
              return $response;
            }
            elseif(count($unexist_post)){
              $response->status = 0;
              $response->message="supply values for: ".implode(',',$unexist_post);
              return $response;
            }
          }
          foreach ($post as $key => $value) {
            if(!empty($validate_cols) && array_search(strtolower($key), $validate_cols)===false)continue;
            elseif($value === ""){
              $response->status = 0;
              $response->message = "$key can't be empty !!!";
              return $response;
            }
          }
        }
        $response = self::insert($post, $param);
        //Check for callback function after submission
        if(isset($param->post_submit_function) && $response->status){
          $response = call_user_func_array($param->post_submit_function, [$response->primary_key]);
        }
      }else{
        $response->status = 0;
        $response->message = "Either param, table property  or submitType is not set !!!";
        return $response;
      }
    }else{
      die("Please add the param name you want to extract details from in you init paramters or form field as 'formName'");
    }
    return $response;
  }

  public function insert($post, $param){
    $post     = (object)$post;
    if(gettype($param) == "string"){
      $cookie	= explode(",", $_COOKIE["siteData"]);
      require_once($cookie[2].$cookie[1]."controllers/ParamControl.php");
      $paramControl = new ParamControl($this);
      $param    = $paramControl->get_params($param);
    }
    $param    = (object)$param;
    $response = new stdClass;
    $build    = array();
    $fields   = self::getTableFields($param->table);
    $proceed  = 0;
    $response->status = 0;
    foreach ($post as $key => $value) {
      if(array_search(strtolower($key), $fields) !==false){
        $v=self::$mydb->real_escape_string($value);
        $v = trim($v);
        $build[] = "$key='{$v}'";
      }
    }
    $build = implode(", ", $build);
    if(empty($post->{$param->primary_key})){
      //Valid unique key if exists
      if(!empty($param->unique_key)){
        if(!empty($post->{$param->unique_key})){
          $unique_value = $post->{$param->unique_key};
          $unique_key = $param->unique_key;
          $unique = self::getFromTable($param->table, "$unique_key=$unique_value",1,1,"",false,[$param->primary_key]);
          if(!empty($unique[0])){
            $response->message = "$unique_value already exists";
          }else $proceed = 1;
        }else  $response->message = "Unique_key $param->unique_key can't be empty !!!";
      }else $proceed = 1;
      if($proceed == 1){
        $build = !empty($param->fixed_values) ? "$build, {$param->fixed_values}" : $build;
        $sql = "INSERT INTO $param->table SET $build";
      }
    }else{
      if(!empty($param->primary_key)){
        if(!empty($post->{$param->primary_key})){
          $build = !empty($param->extra_values) ? "$build, {$param->extra_values}" : $build;
          $primary_key = $post->{$param->primary_key};
          $sql = "UPDATE $param->table SET $build WHERE $param->primary_key='{$primary_key}'";
          $proceed = 1;
        }else{
          $response->message = "Primary key '{$param->primary_key}' was not found in the post";
        }
      }else{
        $response->message = "Primary key has to be set to run Update queries";
      }
    }
    if($proceed === 1){
      //see($sql);
      $query = self::$mydb->query($sql) or die(self::$mydb->error);
      $id = !empty(self::$mydb->insert_id) ? self::$mydb->insert_id : $primary_key;
      $response->status = 1;
      $response->message = "Successful";
      $response->primary_key = $id;
    }
    return $response;
  }

  public function getURIdata($setCookie = false){
    global $_SERVER;
    $protocol = !empty(explode('://', $_SERVER['REQUEST_URI'])[0]) ? explode('://', $_SERVER['REQUEST_URI'])[0] : 'https';
    $request_uri = explode('/', str_replace('https://','',$_SERVER['REQUEST_URI']));
    if((array_search($this->server, $this::getLocalServers()) !==false )){
    	$site_name = !empty($request_uri[1]) ? $request_uri[1] : 'admindb';
    	$page_source = !empty($request_uri[2]) ? $request_uri[2] : 'home';
    	$content_id = !empty($request_uri[3]) ? $request_uri[3] : null;
    	$event = !empty($request_uri[4]) ? $request_uri[4] : null;
    	$parent_page = !empty($request_uri[5]) ? $request_uri[5] : null;
    	$other = !empty($request_uri[6]) ? $request_uri[6] : null;
    	$this->domain = "http://{$this->server}/$site_name/";
    }else{
    	$site = str_replace("www.","",$this->server) ;
    	$this->domain = "https://".str_replace("https://","",$this->server)."/" ;
    	$site_name = 'site';
    	$page_source = !empty($request_uri[1]) ? $request_uri[1] : 'home';
    	$content_id = !empty($request_uri[2]) ? $request_uri[2] : null;
    	$event = !empty($request_uri[3]) ? $request_uri[3] : null;
    	$parent_page = !empty($request_uri[4]) ? $request_uri[4] : null;
    	$other = !empty($request_uri[5]) ? $request_uri[5] : null;
    }
    $page_source = explode("?",$page_source)[0];
    $content_id = explode("?",$content_id)[0];
    if($setCookie === true)
    setcookie(//Set cookie for siteData
      "siteData",
      "{$this->domain},{$this->backend},".absolute_filepath("{$this->domain}"),
      time()+36000,
      "/"
    );
    return((object)[
      "page_source"=>$page_source,
      "content_id"=>$content_id,
      "event"=>$event,
      "other"=>$other,
      "parent_page"=>$parent_page,
      "site"=>$this->domain,
      "backend"=>$this->backend
    ]);
  }

  public function company(){
    $company = new stdClass;
    if(empty(self::$company) || self::$company == null){
      if($this->has_db && $this->isConnected){
        $query = self::$mydb->query("SELECT * FROM company_info WHERE id='1'");
        if($row = $query->fetch_object()){
          $row->branches = json_decode($row->branches);
          $row->slider = json_decode($row->slider);
          $logo = isJson($row->logo_ref);
          if(empty($logo)){//Not an array
            if(empty($row->logo_ref))$row->logo_ref = "{$this->domain}{$this->backend}images/logo.png";
          }
          $row->logo_ref = empty($logo) ? $row->logo_ref : $logo[0]->src;
          $row->favicon = !empty($logo) && !empty($logo[1]) ? $logo[1]->src : $row->logo_ref;
          $company = $row;
          $this->name =  $row->name;
          $this->email =  $row->email;
          self::$company = $company;
        }
      }else{
        $company->error = "Connect to database first";
      }
    }
		return(self::$company);
	}
}
?>
